@@ -10,7 +10,7 @@ class basic_standard_deduction(Variable):
     reference = "https://www.law.cornell.edu/uscode/text/26/63#c_2"
 
     def formula(tax_unit, period, parameters):
-        std = parameters(period).irs.deductions.standard
+        std = parameters(period).gov.irs.deductions.standard
         filing_status = tax_unit("filing_status", period)
         separate_filer_itemizes = tax_unit("separate_filer_itemizes", period)
         claimed_as_dependent_elsewhere = tax_unit(
